# Tomatia

![Screenshot of the TUI](./.github/screenshot.png)

A dead simple pomodoro application build using textual. You can:

- Start a new session (`s`/`space`).
- Stop the current session (`s`/`space`).
- Reset your pomodoro sessions (`r`).
- Quit (`q`).
